@@ -168,8 +168,8 @@ class Job:
 
         if 'START_HOURS_RANGE' in self.environment:
             try:
-                self.start_hour = int(self.environment['STARTS_HOURS_RANGE'])
-                del self.environment['STARTS_HOURS_RANGE']
+                self.start_hour = int(self.environment['START_HOURS_RANGE'].split('-')[0])
+                del self.environment['START_HOURS_RANGE']
             except ValueError:
                 self.log(Log.WARNING, 'invalid START_HOURS_RANGE')
 
@@ -613,7 +613,10 @@ def parse_crontab(filename:str,
                 key = envvar.group(1)
                 value = envvar.group(2)
                 value = value.strip("'").strip('"').strip(' ')
-                environment[key] = value
+                if key == 'PERSISTENT' and value == 'auto':
+                    environment.pop(key, None)
+                else:
+                    environment[key] = value
                 continue
 
             j = Job(filename, line)
@@ -750,6 +753,7 @@ def main() -> None:
             raise
 
     fallback_mailto = None
+    distro_start_hour:dict[str,int] = dict()
 
     if os.path.isfile('/etc/crontab'):
         for job in parse_crontab('/etc/crontab', withuser=True):
@@ -758,11 +762,17 @@ def main() -> None:
                  log(Log.ERR, 'truncated line in /etc/crontab: %s' % job.line)
                  continue
             # legacy boilerplate
-            if '/etc/cron.hourly'  in job.line: continue
-            if '/etc/cron.daily'   in job.line: continue
-            if '/etc/cron.weekly'  in job.line: continue
-            if '/etc/cron.monthly' in job.line: continue
-            generate_timer_unit(job)
+            if '/etc/cron.hourly'  in job.line:
+                continue
+            for schedule in ('daily', 'weekly', 'monthly'):
+                if '/etc/cron.%s' % schedule in job.line:
+                   try:
+                       distro_start_hour[schedule] = int(job.timespec_hour[0])
+                   except ValueError:
+                       log(Log.ERR, 'invalid hour in /etc/crontab: %s' % job.line)
+                   break
+            else:
+                generate_timer_unit(job)
 
     CRONTAB_FILES = files('/etc/cron.d')
     for filename in CRONTAB_FILES:
@@ -799,6 +809,7 @@ def main() -> None:
                 job = Job(filename, filename)
                 job.persistent = True
                 job.period = period
+                job.start_hour = distro_start_hour.get(period, 0)
                 job.boot_delay = i * 5
                 job.command = [filename]
                 job.jobid = period + '-' + basename
